/* ANIMATE.C illustrates animation functions including:
 *      _imagesize     _getimage     _putimage
 */

#include <conio.h>
#include <stddef.h>
#include <stdlib.h>
#include <malloc.h>
#include <graph.h>
#include "timesys.c"

short action[5]  = { _GPSET,   _GPRESET, _GXOR,    _GOR,     _GAND    };
char *descrip[5] = { "PSET  ", "PRESET", "XOR   ", "OR    ", "AND   " };

main()
{
    char far *buffer;
    size_t imsize;
    short i, x, y = 30, mode = _VRES16COLOR;

    while( !_setvideomode( mode ) )         /* Find a valid graphics mode */
	mode--;
    if (mode == _TEXTMONO )
	exit( 1 );                          /* No graphics available      */
    _setcolor( 3 );
    for ( i = 0; i < 1/*5*/; i++ )
    {
	x = 50; y += 40;
	_settextposition( 1, 1 );           /* Display action type        */
/*        _outtext( descrip[i] );*/
					    /* Draw and measure ellipse   */
	_ellipse( _GBORDER, x - 15, y - 15, x + 15, y + 15 );
	_ellipse( _GBORDER, x - 10, y - 10, x + 10, y + 10 );
	_ellipse( _GFILLINTERIOR, x - 6, y - 6, x + 6, y + 6 );
	imsize = (size_t)_imagesize( x - 20, y - 20, x + 20, y + 20 );
	buffer = (char far *)_fmalloc( imsize );
	if ( buffer == (char far *)NULL )
	    exit( !_setvideomode( _DEFAULTMODE ) );
					    /* Get master copy of ellipse */
	_getimage( x - 20, y - 20, x + 20, y + 20, buffer );
	while( x < 600 )                    /* Copy row of ellipses       */
	{                                   /*   with specified action    */
	    x += 1;
	    _putimage( x - 20, y - 20, buffer, action[i] );
	    pause(.03);
	}
	_ffree( buffer );                   /* Free memory                */
/*        getch();*/
    }
    exit( !_setvideomode( _DEFAULTMODE ) );
}

/*
Constant:   _GAND, _GOR, _GPRESET, _GPSET, _GXOR

Include:    <graph.h>

Context:    _putimage, _putimage_w

Synopsis:   Specifies the interaction between the stored image and the
	    image that is already on the screen.

     Constant     Meaning

     _GAND        Transfers the image over an existing image on the
		  screen.  The resulting image is the logical-AND product
		  of the two images: points that had the same color in
		  both the existing image and the new one will remain the
		  same color, while points that have different colors are
		  joined by logical-AND.

     _GOR         Superimposes the image onto an existing image. The new
		  image does not erase the previous screen contents.

     _GPRESET     Transfers the data point by point onto the screen. Each
		  point has the inverse of the color attribute it had when
		  it was taken from the screen by _getimage, producing a
		  negative image.

     _GPSET       Transfers the data point by point onto the screen. Each
		  point has the exact color attribute it had when it was
		  taken from the screen by _getimage.

     _GXOR        Causes the points on the screen to be inverted where a
		  point exists in the image buffer. This behavior is
		  exactly like that of the cursor: when an image is put
		  against a complex background twice, the background is
		  restored unchanged.  This allows you to move an object
		  around without erasing the background.  The _GXOR
		  constant is a special mode often used for animation.
*/
